@@ -5,13 +5,16 @@
 """ Registro de las clases en el admin de django """
 
 from django.contrib import admin
-from .models import  SliderImage, SliderAlbum
+from .models import SliderImage, SliderAlbum
+
 
 class SliderImageAdmin(admin.ModelAdmin):
-    list_display = ('thumb', 'name','description',  'order')
+    list_display = ('thumb', 'name', 'description', 'order')
 admin.site.register(SliderImage, SliderImageAdmin)
 
+
 class SliderAlbumAdmin(admin.ModelAdmin):
-    filter_horizontal = 'images',
-    
+    filter_horizontal = ('images',)
+
+
 admin.site.register(SliderAlbum, SliderAlbumAdmin)
