@@ -6,6 +6,7 @@ from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
 from .models import SliderPlugin
 
+
 class CMSSliderPlugin(CMSPluginBase):
     model = SliderPlugin
     name = 'Slider Plugin'
@@ -14,14 +15,14 @@ class CMSSliderPlugin(CMSPluginBase):
     admin_preview = False
 
     def render(self, context, instance, placeholder):
-        if instance.image_height and instance.image_width:
-            size = (instance.image_width, instance.image_height)
+        if instance.height and instance.width:
+            size = (instance.width, instance.height)
         else:
             size = None
         context.update({
             'object': instance,
             'placeholder': placeholder,
-            'images': instance.album.images.all(),
+            'images': instance.album.images.iterator(),
             'size': size,
         })
         return context
